@@ -10,22 +10,8 @@ sites.get <- function(G, slist = "", all.sites=FALSE, collapse.labels=TRUE,
 		stop("character GRASS data base file name required")
 	if (!is.loaded("sitesget", PACKAGE="GRASS")) interp <- TRUE
 	if (interp) {
-		list.GRASS <- function(type = "rast") {
-		breakup <- function(chars) {
-		tmp <- unlist(strsplit(chars, split="\t"))
-		tmp1 <- character(0)
-		for (i in 1:length(tmp)) tmp1 <- c(tmp1,
-			unlist(strsplit(tmp[i], split=" ")))
-		tmp1[nchar(tmp1) > 0]
-		}
-		res <- system(paste("g.list ", type, sep=""), intern=TRUE)
-		G.list <- character(0)
-		for(i in 3:(length(res)-1)) 
-	    	if (nchar(res[i]) > 0) G.list <- c(G.list, breakup(res[i]))
-		invisible(G.list)
-		}
 
-		G.list <- list.GRASS(type="sites")
+		G.list <- unlist(list.grass(type="site_lists"))
 		res <- slist %in% G.list
 		if (! all(res)) stop(paste("transfer terminated: ",
 			slist[res == FALSE], "GRASS data base file not found"))
